@@ -23,15 +23,15 @@ int32_t SPVM_API_RUNTIME_has_interface_by_id(SPVM_RUNTIME* runtime, int32_t clas
 int32_t SPVM_API_RUNTIME_is_super_class_by_id(SPVM_RUNTIME* runtime, int32_t super_class_basic_type_id, int32_t child_class_basic_type_id);
 
 // Runtime
-SPVM_RUNTIME* SPVM_API_RUNTIME_new_runtime();
+SPVM_RUNTIME* SPVM_API_RUNTIME_new_object();
 void SPVM_API_RUNTIME_prepare(SPVM_RUNTIME* runtime);
-void SPVM_API_RUNTIME_free_runtime(SPVM_RUNTIME* runtime);
+void SPVM_API_RUNTIME_free_object(SPVM_RUNTIME* runtime);
 
 // Runtime information
 SPVM_OPCODE* SPVM_API_RUNTIME_get_opcodes(SPVM_RUNTIME* runtime);
 int32_t SPVM_API_RUNTIME_get_opcodes_length(SPVM_RUNTIME* runtime);
-int32_t* SPVM_API_RUNTIME_get_spvm_32bit_codes(SPVM_RUNTIME* runtime);
-int32_t SPVM_API_RUNTIME_get_spvm_32bit_codes_length(SPVM_RUNTIME* runtime);
+int32_t* SPVM_API_RUNTIME_get_runtime_codes(SPVM_RUNTIME* runtime);
+int32_t SPVM_API_RUNTIME_get_runtime_codes_length(SPVM_RUNTIME* runtime);
 int32_t SPVM_API_RUNTIME_get_classes_length(SPVM_RUNTIME* runtime);
 
 // Basic type
@@ -122,6 +122,6 @@ void* SPVM_API_RUNTIME_get_native_method_address(SPVM_RUNTIME* runtime, int32_t
 void* SPVM_API_RUNTIME_get_precompile_method_address(SPVM_RUNTIME* runtime, int32_t method_id);
 
 SPVM_ALLOCATOR* SPVM_API_RUNTIME_get_allocator(SPVM_RUNTIME* runtime);
-void SPVM_API_RUNTIME_build(SPVM_RUNTIME* runtime, int32_t* spvm_32bit_codes);
+void SPVM_API_RUNTIME_build(SPVM_RUNTIME* runtime, int32_t* runtime_codes);
 
 #endif
