@@ -340,8 +340,8 @@ struct spvm_env_runtime {
   void (*prepare)(void* runtime);
   int32_t* (*get_opcodes)(void* runtime);
   int32_t (*get_opcodes_length)(void* runtime);
-  int32_t* (*get_spvm_32bit_codes)(void* runtime);
-  int32_t (*get_spvm_32bit_codes_length)(void* runtime);
+  int32_t* (*get_runtime_codes)(void* runtime);
+  int32_t (*get_runtime_codes_length)(void* runtime);
   int32_t (*get_classes_length)(void* runtime);
   int32_t (*get_constant_string_id)(void* runtime, const char* string);
   const char* (*get_constant_string_value)(void* runtime, int32_t constant_string_id, int32_t* string_length);
@@ -416,7 +416,7 @@ struct spvm_env_runtime {
   void* object_flag_offset;
   void* object_length_offset;
   void* (*get_allocator)(void* runtime);
-  void (*build)(void* runtime, int32_t* spvm_32bit_codes);
+  void (*build)(void* runtime, int32_t* runtime_codes);
   int32_t (*get_class_parent_class_id)(void* runtime, int32_t class_id);
   int32_t (*get_method_required_args_length)(void* runtime, int32_t method_id);
   int32_t (*get_class_is_pointer)(void* runtime, int32_t class_id);
@@ -433,11 +433,12 @@ struct spvm_env_compiler {
   const char* (*get_start_file)(void* compiler);
   void (*add_module_dir)(void* compiler, const char* module_dir);
   int32_t (*get_module_dirs_length )(void* compiler);
-  const char* (*get_module_dir )(void* compiler, int32_t module_dir_id);
+  const char* (*get_module_dir )(void* compiler, int32_t index);
   int32_t (*compile)(void* compiler, const char* class_name);
   int32_t (*get_error_messages_length)(void* compiler);
   const char* (*get_error_message)(void* compiler, int32_t index);
-  int32_t* (*create_spvm_32bit_codes)(void* compiler, void* allocator);
+  int32_t* (*create_runtime_codes)(void* compiler, void* allocator);
+  void (*clear_module_dirs)(void* compiler);
 };
 
 struct spvm_env_precompile {
