@@ -5,10 +5,10 @@
 
 struct spvm_runtime {
   // SPVM 32bit codes
-  int32_t* spvm_32bit_codes;
+  int32_t* runtime_codes;
 
   // SPVM 32bit codes
-  int32_t spvm_32bit_codes_length;
+  int32_t runtime_codes_length;
   
   // Allocator
   SPVM_ALLOCATOR* allocator;
@@ -103,6 +103,6 @@ void SPVM_RUNTIME_prepare(SPVM_RUNTIME* runtime);
 
 SPVM_ALLOCATOR* SPVM_RUNTIME_get_allocator(SPVM_RUNTIME* runtime);
 
-void SPVM_RUNTIME_build(SPVM_RUNTIME* runtime, int32_t* spvm_32bit_codes);
+void SPVM_RUNTIME_build(SPVM_RUNTIME* runtime, int32_t* runtime_codes);
 
 #endif
