@@ -7,8 +7,6 @@ struct TestCase__Pointer {
   int32_t x;
 };
 
-static const char* FILE_NAME = "TestCase/Pointer.c";
-
 int32_t SPVM__TestCase__Pointer__new(SPVM_ENV* env, SPVM_VALUE* stack) {
   (void)env;
   (void)stack;
@@ -20,7 +18,7 @@ int32_t SPVM__TestCase__Pointer__new(SPVM_ENV* env, SPVM_VALUE* stack) {
   pointer->x = x;
   
   int32_t e;
-  void* struct_object = env->new_pointer_object_by_name(env, stack, "TestCase::Pointer", pointer, &e, __func__, FILE_NAME, __LINE__);
+  void* struct_object = env->new_pointer_object_by_name(env, stack, "TestCase::Pointer", pointer, &e, "TestCase/Pointer.c", __LINE__);
   if (e) { return e; }
   
   stack[0].oval = struct_object;
